##
##  bittorrent.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         bittorrent
Summary:      BitTorrent Peer-To-Peer Networking
URL:          http://www.bittorrent.com/
Vendor:       Bram Cohen
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        P2P
License:      MIT-style
Version:      5.2.2
Release:      20081029

#   list of sources
Source0:      http://download.bittorrent.com/dl/BitTorrent-%{version}.tar.gz
Source1:      rc.bittorrent
Source2:      apache.conf
Patch0:       bittorrent.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823
PreReq:       OpenPKG, openpkg >= 20060823
BuildPreReq:  python, python-net, python-crypto
PreReq:       python, python-net, python-crypto
AutoReq:      no
AutoReqProv:  no

%description
    BitTorrent is a Peer-to-Peer networking server and client.

%track
    prog bittorrent = {
        version   = %{version}
        url       = http://download.bittorrent.com/dl/
        regex     = BitTorrent-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -n BitTorrent-%{version}
    %patch -p0
    %{l_shtool} subst \
        -e 's;#!/usr/bin/env python;#!%{l_prefix}/bin/python;g' \
        *.py

%build

%install
    #   install programs
    rm -rf $RPM_BUILD_ROOT
    HOME=`pwd` %{l_prefix}/bin/python \
        setup.py install \
        --root=$RPM_BUILD_ROOT \
        --prefix=%{l_prefix}

    #   remove GUI part
    rm -f $RPM_BUILD_ROOT%{l_prefix}/bin/bittorrent
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/bittorrent/pixmaps
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/bittorrent/locale
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/bittorrent/doc

    #   wrap executables
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/libexec/bittorrent
    ( cd $RPM_BUILD_ROOT%{l_prefix}/bin
      for bin in *; do
          mv $bin $RPM_BUILD_ROOT%{l_prefix}/libexec/bittorrent/$bin
          ( echo "#!/bin/sh"
            echo "PYTHONPATH=\"%{l_prefix}/libexec/bittorrent\"; export PYTHONPATH"
            echo "exec %{l_prefix}/libexec/bittorrent/$bin \${1+\"\$@\"}"
          ) >$RPM_BUILD_ROOT%{l_prefix}/bin/$bin
          chmod a+x $RPM_BUILD_ROOT%{l_prefix}/bin/$bin
      done
    ) || exit $?

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/bittorrent
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE apache.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/bittorrent/

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.bittorrent} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   create run-time directory
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/bittorrent

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%attr(755,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/bittorrent' \
        '%config %{l_prefix}/etc/bittorrent/*'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} bittorrent status 2>/dev/null`
    [ ".$bittorrent_active" = .yes ] && %{l_rc} bittorrent restart
    exit 0

%preun
    #   before erase, stop service and remove run-time files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} bittorrent stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/bittorrent/* >/dev/null 2>&1 || true
    exit 0

